==> filer-tools-1.0.6.tgz: package/app.js <==
#!/usr/bin/env node
var util = require('util');
var exec = require('child_process').exec;
var fs = require('fs');
var path = require('path');
var touch = require('touch');


var args = process.argv.slice(2);

switch (args[0]) {
  case 'search':
    if (args[1]) {
      var keyword = args[1];
      search(keyword, process.cwd());
      break;
    } else {
      console.log("Please enter a search term.");
      break;
    }
  case 'open':
    if (args[1]) {
      var file = args[1];
      open(file);
      break;
    } else {
      console.log("Please specify a file to open.");
      break;
    }
  case 'new':
    if (args[1] && args[2]) {
      var option = args[1];
      var name = args[2];
      newFile(name, option);
      break;
    } else {
      console.log("Please enter a name.");
      break;
    }
  case 'list':
    list();
    break;
  default:
    console.log("Usage:");
    console.log("filer search <keyword>");
    console.log("filer open <file>");
    console.log("filer new [file | folder] <name>");
    console.log("filer list");
}

// Search function
function search(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '\\' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          search(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}

// Open function
function open(file) {
  exec(getCmd() + ' ' + file);
}

// New file function
function newFile(name, option) {
  var path = process.cwd() + '\\' + name
  if (option == "file") {
    touch(path, function() {
      console.log(name + " created.");
    });
  } else if (option == "folder") {
    fs.mkdir(path, function() {
      console.log(name + " created.");
    });
  } else {
    console.log("Usage:");
    console.log("filer new file <name>");
    console.log("filer new folder <name>");
  }
}

// List function
function list() {
  fs.readdir(process.cwd(), function(err, files) {
    if (err) throw err;
    files.sort(function(a, b) {
      var aIsDir = fs.statSync(process.cwd() + "/" + a).isDirectory();
      var bIsDir = fs.statSync(process.cwd() + "/" + b).isDirectory();
      if (aIsDir && !bIsDir) return -1;
      if (!aIsDir && bIsDir) return 1;
      return a.localeCompare(b);
    });
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var stats = fs.statSync(file);
      if (stats.isDirectory()) {
        console.log("[dir ] " + file);
      } else if (stats.isFile()) {
        console.log("[file] " + file);
      }
    }
  });
}

// Helper functions
function getCmd() {
  switch (process.platform) {
    case 'darwin': return 'open';
    case 'win32': return 'start';
    case 'win64': return 'start';
    default: return 'xdg-open';
  }
}

function openExplorer(file) {
  var os = getCmd();
  if (os == 'start') {
    exec('explorer.exe /select,"' + file + '"');
  } else if (os == 'open') {
    exec('open ' + file);
  } else if (os == 'xdg-open') {
    exec('xdg-open ' + file);
  }
}

==> filer-tools-1.0.7.tgz: package/app.js <==
#!/usr/bin/env node
var util = require('util');
var exec = require('child_process').exec;
var fs = require('fs');
var path = require('path');
var touch = require('touch');


var args = process.argv.slice(2);

switch (args[0]) {
  case 'search':
    if (args[1]) {
      var keyword = args[1];
      search(keyword, process.cwd());
      break;
    } else {
      console.log("Please enter a search term.");
      break;
    }
  case 'open':
    if (args[1]) {
      var file = args[1];
      open(file);
      break;
    } else {
      console.log("Please specify a file to open.");
      break;
    }
  case 'new':
    if (args[1] && args[2]) {
      var option = args[1];
      var name = args[2];
      newFile(name, option);
      break;
    } else {
      console.log("Please enter a name.");
      break;
    }
  case 'list':
    list();
    break;
  default:
    console.log("Usage:");
    console.log("filer search <keyword>");
    console.log("filer open <file>");
    console.log("filer new [file | folder] <name>");
    console.log("filer list");
}

// Search function
function search(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '/' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          search(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}

// Open function
function open(file) {
  exec(getCmd() + ' ' + file);
}

// New file function
function newFile(name, option) {
  var path = process.cwd() + '/' + name
  if (option == "file") {
    touch(path, function() {
      console.log(name + " created.");
    });
  } else if (option == "folder") {
    fs.mkdir(path, function() {
      console.log(name + " created.");
    });
  } else {
    console.log("Usage:");
    console.log("filer new file <name>");
    console.log("filer new folder <name>");
  }
}

// List function
function list() {
  fs.readdir(process.cwd(), function(err, files) {
    if (err) throw err;
    files.sort(function(a, b) {
      var aIsDir = fs.statSync(process.cwd() + "/" + a).isDirectory();
      var bIsDir = fs.statSync(process.cwd() + "/" + b).isDirectory();
      if (aIsDir && !bIsDir) return -1;
      if (!aIsDir && bIsDir) return 1;
      return a.localeCompare(b);
    });
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var stats = fs.statSync(file);
      if (stats.isDirectory()) {
        console.log("[dir ] " + file);
      } else if (stats.isFile()) {
        console.log("[file] " + file);
      }
    }
  });
}

// Helper functions
function getCmd() {
  switch (process.platform) {
    case 'darwin': return 'open';
    case 'win32': return 'start';
    case 'win64': return 'start';
    default: return 'xdg-open';
  }
}

function openExplorer(file) {
  var os = getCmd();
  if (os == 'start') {
    exec('explorer.exe /select,"' + file + '"');
  } else if (os == 'open') {
    exec('open ' + file);
  } else if (os == 'xdg-open') {
    exec('xdg-open ' + file);
  }
}
